==> 4.2.2.zip: quests/README.md <==
<img src="https://i.imgur.com/reQIzd0.png" alt="Logo" align="right">
<div align="center">
  <h1>An extensive questing system</h1>
  <h3>Quests is the easy-to-use, open-source plugin for the creation and execution of quests on Minecraft servers. Players can take on multiple quests simultaneously, completing them for stellar rewards and unlockables.</h3>

[![Build Status](https://ci.codemc.org/job/PikaMug/job/Quests/badge/icon)](https://ci.codemc.org/job/PikaMug/job/Quests/)
[![Downloads](https://img.shields.io/spiget/downloads/3711)](https://www.spigotmc.org/resources/quests.3711/)
[![Rating](https://img.shields.io/spiget/stars/3711)](https://www.spigotmc.org/resources/quests.3711/)
[![Crowdin](https://d322cqt584bo4o.cloudfront.net/translate-quests/localized.svg)](https://crowdin.com/project/translate-quests)
[![Discord](https://img.shields.io/discord/506992958894243860)](https://discordapp.com/invite/QdJAv2G7qg)
[![Players](https://img.shields.io/bstats/players/9528)](https://bstats.org/plugin/bukkit/Quests%20Classic/9528)
[![Server](https://img.shields.io/bstats/servers/9528)](https://bstats.org/plugin/bukkit/Quests%20Classic/9528)
</div>

Download
---

Distributed through these fine vendors:
- CurseForge (https://www.curseforge.com/minecraft/bukkit-plugins/quests/)
- SpigotMC (https://www.spigotmc.org/resources/quests.3711/)
- MC-Market (https://www.mc-market.org/resources/19187/)

Usage
---

Read about usage in the documentation: https://pikamug.gitbook.io/quests/

Compile
---

Requires Java 8 and Maven: https://pikamug.gitbook.io/quests/master/plugin-compilation

Translate
---

Help localize into your language:
- Project (https://crowdin.com/project/translate-quests)
- Documentation (https://github.com/PikaMug/QuestsDoc)

==> 4.4.1.zip: quests/README.md <==
<img src="https://i.imgur.com/reQIzd0.png" alt="Logo" align="right">
<div align="center">
  <h1>An extensive questing system</h1>
  <h3>Quests is the easy-to-use, open-source plugin for the creation and execution of quests on Minecraft servers. Players can take on multiple quests simultaneously, completing them for stellar rewards and unlockables.</h3>

[![Build Status](https://ci.codemc.org/job/PikaMug/job/Quests/badge/icon)](https://ci.codemc.org/job/PikaMug/job/Quests/)
[![Downloads](https://img.shields.io/spiget/downloads/3711)](https://www.spigotmc.org/resources/quests.3711/)
[![Rating](https://img.shields.io/spiget/stars/3711)](https://www.spigotmc.org/resources/quests.3711/)
[![Crowdin](https://d322cqt584bo4o.cloudfront.net/translate-quests/localized.svg)](https://crowdin.com/project/translate-quests)
[![Discord](https://img.shields.io/discord/506992958894243860)](https://discordapp.com/invite/QdJAv2G7qg)
[![Players](https://img.shields.io/bstats/players/9528)](https://bstats.org/plugin/bukkit/Quests%20Classic/9528)
[![Server](https://img.shields.io/bstats/servers/9528)](https://bstats.org/plugin/bukkit/Quests%20Classic/9528)
</div>

Download
---

Distributed through these fine vendors:
- CurseForge (https://www.curseforge.com/minecraft/bukkit-plugins/quests/)
- SpigotMC (https://www.spigotmc.org/resources/quests.3711/)
- MC-Market (https://www.mc-market.org/resources/19187/)

Usage
---

Read about usage in the documentation: https://pikamug.gitbook.io/quests/

Compile
---

Java 8 and Maven required: https://pikamug.gitbook.io/quests/master/plugin-compilation

Translate
---

Help localize into your language:
- Project (https://crowdin.com/project/translate-quests)
- Documentation (https://github.com/PikaMug/QuestsDoc)
